@@ -1,10 +1,10 @@
 psplitnorm <-
-function(x, mean = 0, sd = 1, skew = 0, sd1 = NULL, sd2 = NULL) {
-  n <- max(length(x),length(mean),length(sd),length(skew),length(sd1),length(sd2))
+function(x, mode = 0, sd = 1, skew = 0, sd1 = NULL, sd2 = NULL) {
+  n <- max(length(x),length(mode),length(sd),length(skew),length(sd1),length(sd2))
   if(length(x)<n)
     x[1:n]<-x
-  if(length(mean)<n)
-    mean[1:n]<-mean
+  if(length(mode)<n)
+    mode[1:n]<-mode
   if(length(sd)<n)
     sd[1:n]<-sd
   if(length(skew)<n)
@@ -32,9 +32,9 @@ function(x, mean = 0, sd = 1, skew = 0, sd1 = NULL, sd2 = NULL) {
   c <- sqrt(2/pi)/(sd1 + sd2)
   k <- f 
   k[] <- x #change name of x to match formula
-  k1 <- k <= mean
-  k2 <- k > mean
-  f[k1] <- (c[k1] * sqrt(2 * pi) * sd1[k1] * pnorm((k[k1] - mean[k1])/sd1[k1]))
-  f[k2] <- (1 - c[k2] * sqrt(2 * pi) * sd2[k2] * (1 - pnorm((k[k2] - mean[k2])/sd2[k2])))
+  k1 <- k <= mode
+  k2 <- k > mode
+  f[k1] <- (c[k1] * sqrt(2 * pi) * sd1[k1] * pnorm((k[k1] - mode[k1])/sd1[k1]))
+  f[k2] <- (1 - c[k2] * sqrt(2 * pi) * sd2[k2] * (1 - pnorm((k[k2] - mode[k2])/sd2[k2])))
   return(f)
 }
